import 'package:dio/dio.dart';

import '../../trakt.dart';

class TraktApiInterceptor extends InterceptorsWrapper {
  final Trakt trakt;

  TraktApiInterceptor(this.trakt);

  @override
  Future onRequest(RequestOptions options) {
    // Add Headers
    setMapValues(options.headers, 'Authorization', null, true);
    setMapValues(options.headers, 'trakt-api-version',
        trakt.apiConfiguration.apiVersion, false);
    setMapValues(options.headers, 'content-type', 'application/json', false);

    // Set Client Id and Client Secret Everywhere
    //Headers
    setMapValues(options.headers, 'trakt-api-key',
        trakt.apiConfiguration.clientId, false);
    // Body
    // TODO: Test what happens in case of post request with values that shouldn't be there.
    setMapValues(
        options.data, 'client_id', trakt.apiConfiguration.clientId, false);
    setMapValues(options.data, 'client_secret-id',
        trakt.apiConfiguration.clientSecret, false);

    return super.onRequest(options);
  }

  void setMapValues(Map<String, dynamic> source, String key, String defaultVal,
      bool isBearer) {
    String finalVal = defaultVal;
    if (source.containsKey(key) && source[key] != null) {
      finalVal = (source[key] as String);
    }

    if (finalVal != null) {
      if (isBearer) {
        var finalValList = finalVal.split(" ");
        finalVal = 'Bearer ${finalValList.last}';
      }

      source.addAll({key: '${finalVal}'});
    }
  }

  @override
  Future onResponse(Response response) {
    // Set pagination headers to data
    // setMapValues(
    //     response.data, 'page', response.headers['X-Pagination-Page'], false);
    // setMapValues(
    //     response.data, 'limit', response.headers['X-Pagination-Limit'], false);
    // setMapValues(response.data, 'totalPages',
    //     response.headers['X-Pagination-Page-Count'], false);
    // setMapValues(response.data, 'totalItems',
    //     response.headers['X-Pagination-Item-Count'], false);

    return super.onResponse(response);
  }

  @override
  Future onError(DioError error) {
    return super.onError(error);
  }
}
