import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'movies.g.dart';

@RestApi()
abstract class Movies {
  factory Movies(Dio dio, {String baseUrl}) = _Movies;

  @GET('/movies/trending')
  Future<HttpResponse<dynamic>> getTrending({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/popular')
  Future<HttpResponse<dynamic>> getPopular({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/recommended/{period}')
  Future<HttpResponse<dynamic>> getRecommended({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/played/{period}')
  Future<HttpResponse<dynamic>> getMostPlayed({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/watched/{period}')
  Future<HttpResponse<dynamic>> getMostWatched({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/collected/{period}')
  Future<HttpResponse<dynamic>> getMostCollected({
    @Path('period') TimePeriod timePeriod,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/anticipated')
  Future<HttpResponse<dynamic>> getAnticipated({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Query('query') String query,
    @Query('years') String years,
    @Query('genres') String genres,
    @Query('languages') String languages,
    @Query('countries') String countries,
    @Query('runtimes') String runtimes,
    @Query('certifications') String certifications,
    @Query('networks') String networks,
    @Query('status') String status,
    @Query('ratings') String ratings,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/boxoffice')
  Future<HttpResponse<dynamic>> getBoxOffice({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/updates/{start_date}')
  Future<HttpResponse<dynamic>> getUpdated({
    @Path('start_date') String startDate,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}')
  Future<HttpResponse<dynamic>> getDetails(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/aliases')
  Future<HttpResponse<dynamic>> getAliases(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/releases/{country}')
  Future<HttpResponse<dynamic>> getReleases(
    @Path('id') String movieId, {
    @Path('country') String country,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/translations/{language}')
  Future<HttpResponse<dynamic>> getTranslations(
    @Path('id') String movieId, {
    @Path('language') String language,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/comments/{sort}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') String movieId, {
    @Path('sort') MovieCommentsSortBy movieCommentsSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/lists/{type}/{sort}')
  Future<HttpResponse<dynamic>> getLists(
    @Path('id') String movieId, {
    @Path('type') MediaListTypes mediaListTypes,
    @Path('sort') MediaListSortBy mediaListSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/people')
  Future<HttpResponse<dynamic>> getPeople(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/ratings')
  Future<HttpResponse<dynamic>> getRatingDistribution(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/related')
  Future<HttpResponse<dynamic>> getRelated(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/stats')
  Future<HttpResponse<dynamic>> getStats(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/movies/{id}/watching')
  Future<HttpResponse<dynamic>> getUsersWatching(
    @Path('id') String movieId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
