import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'people.g.dart';

@RestApi()
abstract class People {
  factory People(Dio dio, {String baseUrl}) = _People;

  @GET('/people/{id}')
  Future<HttpResponse<dynamic>> getDetails(
    @Path('id') String personId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/people/{id}/movies')
  Future<HttpResponse<dynamic>> getMovies(
    @Path('id') String personId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/people/{id}/shows')
  Future<HttpResponse<dynamic>> getShows(
    @Path('id') String personId, {
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/people/{id}/lists/{type}/{sort}')
  Future<HttpResponse<dynamic>> getLists(
    @Path('id') String personId, {
    @Path('type') PeopleListTypes peopleListTypes,
    @Path('id') PeopleListSortBy peopleListSortBy,
    @Query('client_id') String clientId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
