import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'seasons.g.dart';

@RestApi()
abstract class Seasons {
  factory Seasons(Dio dio, {String baseUrl}) = _Seasons;

  @GET('/shows/{id}/seasons')
  Future<HttpResponse<dynamic>> getAllSeasons(
    @Path('id') String showId, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}')
  Future<HttpResponse<dynamic>> getSingleSeason(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('translations') String translations,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/comments/{sort}')
  Future<HttpResponse<dynamic>> getComments(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Path('sort') ShowCommentsSortBy showCommentsSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/lists/{type}/{sort}')
  Future<HttpResponse<dynamic>> getLists(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Path('type') MediaListTypes mediaListTypes,
    @Path('sort') MediaListSortBy mediaListSortBy,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('page') int page,
    @Query('limit') int limit,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/people')
  Future<HttpResponse<dynamic>> getPeople(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/ratings')
  Future<HttpResponse<dynamic>> getRatingDistribution(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/ratings')
  Future<HttpResponse<dynamic>> getStats(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/shows/{id}/seasons/{season}/watching')
  Future<HttpResponse<dynamic>> getUsersWatching(
    @Path('id') String showId,
    @Path('season') int seasonNumber, {
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
