import 'package:dio/dio.dart';
import 'package:retrofit/retrofit.dart';
import '../../../trakt.dart';

part 'synch.g.dart';

@RestApi()
abstract class Synch {
  factory Synch(Dio dio, {String baseUrl}) = _Synch;

  @GET('/sync/last_activities')
  Future<HttpResponse<dynamic>> getLastActivities({
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/playback/{type}')
  Future<HttpResponse<dynamic>> getPlaybackProgress({
    @Path('type') AlternateMediaType alternateMediaType,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('start_at') String startAt,
    @Query('end_at') String endAt,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @DELETE('/sync/playback/{id}')
  Future<HttpResponse<dynamic>> removePlayback({
    @Path('id') int playbackId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/collection/{type}')
  Future<HttpResponse<dynamic>> getCollectedItems({
    @Path('type') AlternateMediaType alternateMediaType,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/collection')
  Future<HttpResponse<dynamic>> addToCollection({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/collection/remove')
  Future<HttpResponse<dynamic>> removeFromCollection({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/watched/{type}')
  Future<HttpResponse<dynamic>> getWatchedItems({
    @Path('type') AlternateMediaType alternateMediaType,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/history/{type}/{id}')
  Future<HttpResponse<dynamic>> getHistory({
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('id') int mediaId,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('start_at') String startAt,
    @Query('end_at') String endAt,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/history')
  Future<HttpResponse<dynamic>> addToHistory({
    @Body() SynchHistoryBody synchHistoryBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/history/remove')
  Future<HttpResponse<dynamic>> removeFromHistory({
    @Body() SynchHistoryBody synchHistoryBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/ratings/{type}/{rating}')
  Future<HttpResponse<dynamic>> getRatings({
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('rating') int rating,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('start_at') String startAt,
    @Query('end_at') String endAt,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/ratings')
  Future<HttpResponse<dynamic>> addRatings({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/ratings/remove')
  Future<HttpResponse<dynamic>> remoteRatings({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/watchlist/{type}/{sort}')
  Future<HttpResponse<dynamic>> getWatchlist({
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('sort') ListSortBy listSortBy,
    @Path('rating') int rating,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('start_at') String startAt,
    @Query('end_at') String endAt,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/watchlist')
  Future<HttpResponse<dynamic>> addToWatchlist({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/watchlist/remove')
  Future<HttpResponse<dynamic>> removeFromWatchlist({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @GET('/sync/recommendations/{type}/{sort}')
  Future<HttpResponse<dynamic>> getPersonalRecommendations({
    @Path('type') AlternateMediaType alternateMediaType,
    @Path('sort') ListSortBy listSortBy,
    @Path('rating') int rating,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('start_at') String startAt,
    @Query('end_at') String endAt,
    @Query('page') int page,
    @Query('limit') int limit,
    @Query('client_id') String clientId,
    @Query('extended') String extendedInfo,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/recommendations')
  Future<HttpResponse<dynamic>> addToPersonalRecommendations({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });

  @POST('/sync/recommendations/remove')
  Future<HttpResponse<dynamic>> removeFromPersonalRecommendations({
    @Body() SynchCollectionBody synchCollectionBody,
    @Header('content-type') String contentType,
    @Header('trakt-api-version') String traktApiVersion,
    @Header('trakt-api-key') String traktApiKey,
    @Header('Authorization') String accessToken,
    @Query('client_id') String clientId,
    @Queries() Map<String, dynamic> additionalQueries,
  });
}
